@@ -438,8 +438,11 @@ class Parser(object):
     pi_data_to_dict = False
 
     def __init__(self, data=None, root=None, dispatch_depth=-1,
-                 delete_node_after_dispatch=True):
+                 delete_node_after_dispatch=True,
+                 expand_internal_entities=False):
         self._parser = ParserCreate()
+        if(not expand_internal_entities):
+            self._parser.DefaultHandler = self._parser.DefaultHandler
         self._parser.StartElementHandler = self.start
         self._parser.EndElementHandler = self.end
         self._parser.CharacterDataHandler = self.data
@@ -542,7 +545,7 @@ class Document(object):
             else:
                 filename = None
         else:
-            file_ = open(source, 'r', 'utf-8')
+            file_ = open(source, 'r', encoding='utf-8')
             content = file_.read()
             file_.close()
             filename = source
